@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* 
  * gnome-cups-printer.c - 
  * Copyright (C) 2002, Ximian, Inc.
@@ -274,6 +274,13 @@ attributes_update_cb (guint id,
 #undef MAP_INT
 #undef MAP_STRING
 
+/* JEG 
+ * Disable this for now.  The default SuSE network config does not
+ * produce a resolvable hostname for the localhost and cups has a bug
+ * that will produce an infinite loop when presented with an invalid
+ * hostname.  This will also produce a hang if the remote printer is
+ * unavailable and we do a syncronous lookup. */
+static gboolean go_directly_to_printer_when_possible = FALSE;
 
 static void
 update_attributes (GnomeCupsPrinter *printer)
@@ -281,18 +288,19 @@ update_attributes (GnomeCupsPrinter *printer)
 	ipp_t *request;
 	char *host;
 	static const char *attributes[] = {
-	  "printer-state", "queued-job-count",
-	  "printer-location", "printer-info",
-	  "printer-state-message", "device-uri",
-	  "printer-state-reasons", "printer-info",
-	  "printer-make-and-model", "printer-uri-supported"
+	  "printer-state",		"queued-job-count",
+	  "printer-location",		"printer-info",
+	  "printer-state-message",	"device-uri",
+	  "printer-state-reasons",	"printer-info",
+	  "printer-make-and-model",	"printer-uri-supported"
 	};
 
 	if (printer->details->attributes_request_id > 0) {
 		return;
 	}
 	
-	if (printer->details->attributes_set) {
+	if (go_directly_to_printer_when_possible &&
+	    printer->details->attributes_set) {
 		request = gnome_cups_request_new_for_printer (IPP_GET_PRINTER_ATTRIBUTES,
 							      printer);
 		gnome_cups_request_add_requested_attributes (request, 
@@ -760,6 +768,30 @@ gnome_cups_printer_get_name (GnomeCupsPrinter *printer)
 
 	return printer->details->printer_name;
 }
+void
+gnome_cups_printer_set_name (GnomeCupsPrinter *printer,
+			     const char *name,
+			     GError **error)
+{
+	ipp_t *request;
+	ipp_t *response;
+
+	g_return_if_fail (GNOME_CUPS_IS_PRINTER (printer));
+	g_return_if_fail (name != NULL);
+
+	if (!strcmp (name, printer->details->printer_name))
+		return;
+
+	request = gnome_cups_request_new_for_printer (IPP_SET_PRINTER_ATTRIBUTES, printer);
+	ippAddString (request,	IPP_TAG_PRINTER, IPP_TAG_NAME,
+		"printer-name", NULL, gnome_cups_strdup (name));
+	response = gnome_cups_request_execute (request, NULL, "/admin/", error);
+	ippDelete (response);
+
+	g_free (printer->details->printer_name);
+	printer->details->printer_name = g_strdup (name);
+	update_attributes (printer);
+}
 
 gboolean
 gnome_cups_printer_is_gone (GnomeCupsPrinter *printer)
@@ -914,7 +946,7 @@ gnome_cups_printer_set_description (GnomeCupsPrinter *printer,
 		return;
 	}
 
-	request = gnome_cups_request_new_for_printer (CUPS_ADD_PRINTER,
+	request = gnome_cups_request_new_for_printer (IPP_SET_PRINTER_ATTRIBUTES,
 						      printer);
 	ippAddString (request, IPP_TAG_PRINTER, IPP_TAG_TEXT,
 		      "printer-info", NULL, description);
@@ -946,10 +978,10 @@ gnome_cups_printer_set_location (GnomeCupsPrinter *printer,
 		return;
 	}
 
-	request = gnome_cups_request_new_for_printer (CUPS_ADD_PRINTER,
-						      printer);
+	request = gnome_cups_request_new_for_printer (
+		IPP_SET_PRINTER_ATTRIBUTES, printer);
 	ippAddString (request, IPP_TAG_PRINTER, IPP_TAG_TEXT,
-		      "printer-location", NULL, location);
+		"printer-location", NULL, location);
 	response = gnome_cups_request_execute (request, NULL, "/admin/", error);
 	ippDelete (response);
 	update_attributes (printer);
@@ -964,8 +996,7 @@ gnome_cups_printer_pause (GnomeCupsPrinter *printer,
 
 	g_return_if_fail (GNOME_CUPS_IS_PRINTER (printer));
 	
-	request = gnome_cups_request_new_for_printer (IPP_PAUSE_PRINTER,
-						      printer);
+	request = gnome_cups_request_new_for_printer (IPP_PAUSE_PRINTER, printer);
 	response = gnome_cups_request_execute (request, NULL, "/admin/", error);
 	ippDelete (response);
 	update_attributes (printer);
@@ -980,8 +1011,7 @@ gnome_cups_printer_resume (GnomeCupsPrinter *printer,
 
 	g_return_if_fail (GNOME_CUPS_IS_PRINTER (printer));
 	
-	request = gnome_cups_request_new_for_printer (IPP_RESUME_PRINTER,
-						      printer);
+	request = gnome_cups_request_new_for_printer (IPP_RESUME_PRINTER, printer);
 	response = gnome_cups_request_execute (request, NULL, "/admin/", error);
 	ippDelete (response);
 	update_attributes (printer);	
@@ -1601,7 +1631,9 @@ gchar *
 _gnome_cups_printer_get_host (GnomeCupsPrinter *printer)
 {
 	gchar *host = NULL;
-	if (printer->details->printer_uri) {
+
+	if (go_directly_to_printer_when_possible &&
+	    printer->details->printer_uri) {
 		gchar *x, *y;
 
 		x = strstr (printer->details->printer_uri, "://");
