@@ -101,9 +101,12 @@ GnomeCupsPrinter  *     gnome_cups_printer_get               (const char
 GnomeCupsPrinter  *     gnome_cups_printer_get_existing      (const char              *name);
 void                    gnome_cups_printer_unref             (GnomeCupsPrinter        *printer);
 const char *            gnome_cups_printer_get_name          (GnomeCupsPrinter        *printer);
+void			gnome_cups_printer_set_name 	     (GnomeCupsPrinter	      *printer,
+							      const char	      *name,
+							      GError		     **error);
 gboolean                gnome_cups_printer_is_gone           (GnomeCupsPrinter        *printer);
 
-gboolean		gnome_cups_printer_get_attributes_initialized (GnomeCupsPrinter        *printer);
+gboolean		gnome_cups_printer_get_attributes_initialized (GnomeCupsPrinter *printer);
 
 /* Status and attributes */
 
