@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* FIXME: gone printers that come back to life */
 
 #include <config.h>
@@ -423,24 +424,19 @@ gnome_cups_queue_get_job (GnomeCupsQueue *queue,
 static void
 update_queue (GnomeCupsQueue *queue)
 {
-	GnomeCupsPrinter *printer;
 	gchar *printer_host = NULL;
-
-	printer = gnome_cups_printer_get_existing (queue->details->queue_name);
+	GnomeCupsPrinter *printer = gnome_cups_printer_get_existing (
+		queue->details->queue_name);
 	
-	if (printer) {
+	if (printer != NULL) {
 		printer_host = _gnome_cups_printer_get_host (printer);
 		g_object_unref (printer);
-	}
-
-	if (!printer_host)
+	} else
 		return;
 
-	if (gnome_cups_printer_get_is_local (printer))
-		get_jobs_on_server (queue, NULL);
-	else
-		get_jobs_on_server (queue, printer_host);
-
+	get_jobs_on_server (queue,
+		(gnome_cups_printer_get_is_local (printer) || printer_host == NULL)
+		? NULL : printer_host);
 	g_free (printer_host);
 }
 
